Object Widget
-------------

The `ObjectWidget` widget is about rendering a schema's fields as a single
widget.

.. toctree::
   :maxdepth: 1

   Overview <object>
   Integration with single (non-multi) widgets <object_single_integration>
   Integration with MultiWidget (Overview) <objectmulti>
   Integration with MultiWidget of dict <object_multi_dict_integration>
   Integration with MultiWidget of list <object_multi_list_integration>
